@@ -130,7 +130,7 @@ class ConsumerStreamPython:
             )
             assert project == user_project  # TODO: handle this better
 
-        except auth.exceptions.DefaultCredentialsError:
+        except (TypeError, auth.exceptions.DefaultCredentialsError):
             self.authenticate_with_oauth()
             self.credentials = credentials_from_session(self.oauth2)
 
@@ -298,13 +298,14 @@ class ConsumerStreamPython:
 
         # run user callback
         if kwargs["user_callback"] is not None:
+            # get args for user_callback
+            args = []  # requires args are ordered properly here & in user_callback
+            if kwargs.get("send_alert_bytes", False):
+                args.append(message.data)
+            if kwargs.get("send_metadata", False):
+                args.append(metadata_dict)
             try:
-                # call user_callback with appropriate args
-                args = {}  # requires args are ordered properly here & in user_callback
-                if kwargs.get("send_alert_bytes", False):
-                    args.update(message.data)
-                if kwargs.get("send_metadata", False):
-                    args.update(metadata_dict)
+                # execute user callback
                 success = kwargs["user_callback"](alert_dict, *args, **kwargs)  # bool
 
             except Exception as e:
